# sourcelib

[![PyPI version](https://badge.fury.io/py/sourcelib.svg)](https://badge.fury.io/py/sourcelib)
[![tests](https://github.com/martvanrijthoven/source-lib/actions/workflows/tests.yml/badge.svg)](https://github.com/martvanrijthoven/source-lib/actions/workflows/tests.yml)
[![Coverage Status](https://coveralls.io/repos/github/martvanrijthoven/source-lib/badge.svg?branch=main)](https://coveralls.io/github/martvanrijthoven/source-lib?branch=main)
[![codeinspector](https://api.codiga.io/project/34464/score/svg)](https://app.codiga.io/public/project/34464/source-lib/dashboard)


# Main Features

 - Associate different files 
 - Collect associated files via files, folders, and/or YAML.
 - Copy associated files 


# Example Notebook

https://github.com/martvanrijthoven/source-lib/blob/main/docs/source/notebooks/Example.ipynb